@@ -215,7 +215,16 @@ unsafe extern "C" fn sax_start_element_ns_cb(
     let qual_name = make_qual_name(prefix, uri, localname);
 
     let nb_attributes = nb_attributes as usize;
-    let attrs = Attributes::new_from_xml2_attributes(nb_attributes, attributes as *const *const _);
+    let attrs =
+        match Attributes::new_from_xml2_attributes(nb_attributes, attributes as *const *const _) {
+            Ok(attrs) => attrs,
+            Err(e) => {
+                xml2_parser.state.error(e);
+                let parser = xml2_parser.parser.get();
+                xmlStopParser(parser);
+                return;
+            }
+        };
 
     if let Err(e) = xml2_parser.state.start_element(qual_name, attrs) {
         let _: () = e; // guard in case we change the error type later
